==> konoha-0.2.2-rc2.tar.gz: konoha-0.2.2-rc2/class/konoha/knh_Connection_api1.c <==
/****************************************************************************
 * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER
 *
 * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
 *           (c) 2008-      Konoha Software Foundation
 * All rights reserved.
 *
 * You may choose one of the following two licenses when you use konoha.
 * See www.konohaware.org/license.html for further information.
 *
 * (1) GNU General Public License 2.0      (with    KONOHA_UNDER_GPL2)
 * (2) Konoha Software Foundation License 1.0
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

/* ************************************************************************ */

#include"commons.h"

/* ************************************************************************ */

#ifdef __cplusplus
extern "C" {
#endif

/* ======================================================================== */
/* [constructor] */

/* ------------------------------------------------------------------------ */
/* @method Connection! Connection.new(String! urn) */

METHOD knh__Connection_new(Ctx *ctx, knh_sfp_t *sfp)
{
	Connection *o = (Connection*)sfp[0].o;
	knh_Connection_open(ctx, o, (String*)sfp[1].s);
	KNH_RETURN(ctx, sfp, sfp[0].o);
}

/* ======================================================================== */
/* [method] */

static
void knh_Connection_connect(Ctx *ctx, Connection *o, ResultSet *rs)
{
	KNH_SETv(ctx, DP(rs)->conn, o);
	DP(rs)->dbcurfree = DP(o)->df->dbcurfree;
}

/* ------------------------------------------------------------------------ */
/* @method ResultSet Connection.query(String! query) */

METHOD knh__Connection_query(Ctx *ctx, knh_sfp_t *sfp)
{
	Connection *o = (Connection*)sfp[0].o;
	String *query = (String*)sfp[1].o;
	ResultSet *rs = DP(o)->df->dbquery(ctx, DP(o)->conn, knh_String_tobytes(query));
	if(IS_NOTNULL(rs)) {
		knh_Connection_connect(ctx, o, rs);
	}
	KNH_RETURN(ctx, sfp, rs);
}

/* ======================================================================== */

/* ------------------------------------------------------------------------ */

#ifdef __cplusplus
}
#endif

==> konoha-0.2.3.tar.gz: konoha-0.2.3/class/konoha/knh_Connection_api1.c <==
/****************************************************************************
 * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER
 *
 * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
 *           (c) 2008-      Konoha Software Foundation
 * All rights reserved.
 *
 * You may choose one of the following two licenses when you use konoha.
 * See www.konohaware.org/license.html for further information.
 *
 * (1) GNU General Public License 2.0      (with    KONOHA_UNDER_GPL2)
 * (2) Konoha Software Foundation License 1.0
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

/* ************************************************************************ */

#include"commons.h"

/* ************************************************************************ */

#ifdef __cplusplus
extern "C" {
#endif

/* ======================================================================== */
/* [constructor] */

/* ------------------------------------------------------------------------ */
/* @method Connection! Connection.new(String! urn) */

METHOD knh__Connection_new(Ctx *ctx, knh_sfp_t *sfp)
{
	Connection *o = (Connection*)sfp[0].o;
	knh_Connection_open(ctx, o, (String*)sfp[1].s);
	KNH_RETURN(ctx, sfp, sfp[0].o);
}

/* ======================================================================== */
/* [method] */

/* ------------------------------------------------------------------------ */
/* @method ResultSet! Connection.query(String! query) */

METHOD knh__Connection_query(Ctx *ctx, knh_sfp_t *sfp)
{
	Connection *o = (Connection*)sfp[0].o;
	String *query = (String*)sfp[1].o;
	ResultSet *rs = new_ResultSet(ctx);
	KNH_SETv_FOR_RCGC(ctx, sfp[2].o, rs);
	knh_dbcur_t *dbcur = DP(o)->df->dbquery(ctx, DP(o)->conn, knh_String_tobytes(query), rs);
	if(dbcur != NULL) {
		DP(rs)->dbcur = dbcur;
		DP(rs)->dbcur_free = DP(o)->df->dbcurfree;
	}
	else {
		DP(rs)->dbcur = NULL;
		DP(rs)->dbcur_free = knh_dbcurfree__NOP;
	}
	KNH_SETv(ctx, DP(rs)->conn, o);
	KNH_RETURN(ctx, sfp, rs);
}

/* ------------------------------------------------------------------------ */
/* @method void Connection.exec(String! query) */

METHOD knh__Connection_exec(Ctx *ctx, knh_sfp_t *sfp)
{
	Connection *o = (Connection*)sfp[0].o;
	String *query = (String*)sfp[1].o;
	DP(o)->df->dbquery(ctx, DP(o)->conn, knh_String_tobytes(query), NULL);
	KNH_RETURN_void(ctx, sfp);
}

/* ======================================================================== */

/* ------------------------------------------------------------------------ */

#ifdef __cplusplus
}
#endif
